CustomKeysParser class

Utility class for parsing custom keys from message data.

Constructors

CustomKeysParser()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseCustomKeys(dynamic keysData) → Map<String, String>?
Parses a list of key-value pairs into a Map.