CartEvent class

Inheritance

Constructors

CartEvent.addToCart(LineItem lineItem)
factory
CartEvent.removeFromCart(LineItem lineItem)
factory
CartEvent.replaceCart(List<LineItem> lineItems)
factory

Properties

attributes → Map<String, dynamic>?
finalinherited
category → EventCategory
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
lineItems → List<LineItem>
final
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited