LineItem class

Constructors

LineItem(String catalogObjectType, String catalogObjectId, int quantity, double price, String currency, [Map<String, dynamic> attributes = const {}])

Properties

attributes ↔ Map<String, dynamic>
getter/setter pair
catalogObjectId ↔ String
getter/setter pair
catalogObjectType ↔ String
getter/setter pair
currency ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
price ↔ double
getter/setter pair
quantity ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited