Order class

Constructors

Order(String id, List<LineItem> lineItems, double totalValue, String currency, [Map<String, dynamic> attributes = const {}])

Properties

attributes ↔ Map<String, dynamic>
getter/setter pair
currency ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
lineItems ↔ List<LineItem>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalValue ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited