InboxMessage class

Constructors

InboxMessage({required String id, String? title, String? alert, String? custom, Map<String, String>? customKeys, required bool deleted, DateTime? endDateUtc, required bool read, DateTime? sendDateUtc, String? sound, DateTime? startDateUtc, String? subject, String? url, Media? media, String? subtitle, String? inboxMessage, String? inboxSubtitle, NotificationMessage? notificationMessage, int? messageType})
InboxMessage.fromJson(Map<String, dynamic> json)
factory

Properties

alert → String?
final
custom → String?
final
customKeys → Map<String, String>?
final
deleted ↔ bool
getter/setter pair
endDateUtc → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
inboxMessage → String?
final
inboxSubtitle → String?
final
media → Media?
final
messageType → int?
final
notificationMessage → NotificationMessage?
final
read ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendDateUtc → DateTime?
final
sound → String?
final
startDateUtc → DateTime?
final
subject → String?
final
subtitle → String?
final
title → String?
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited