NotificationMessage class

Constructors

NotificationMessage({required String id, required String alert, String? sound, String? soundName, String? title, String? subtitle, required String type, required String trigger, String? url, String? mediaUrl, String? mediaAltText, Map<String, String>? customKeys, String? custom, Map<String, String>? payload})
NotificationMessage.fromJson(Map<String, dynamic> json)
factory

Properties

alert → String
final
custom → String?
final
customKeys → Map<String, String>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
mediaAltText → String?
final
mediaUrl → String?
final
payload → Map<String, String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sound → String?
final
soundName → String?
final
subtitle → String?
final
title → String?
final
trigger → String
final
type → String
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited